Merge "VoIP JNI: Force AEC on for tuna board"
diff --git a/jni/rtp/AudioGroup.cpp b/jni/rtp/AudioGroup.cpp
index 529b425..5f07bb5 100644
--- a/jni/rtp/AudioGroup.cpp
+++ b/jni/rtp/AudioGroup.cpp
@@ -628,12 +628,13 @@
     if (mode < 0 || mode > LAST_MODE) {
         return false;
     }
     //FIXME: temporary code to overcome echo and mic gain issues on herring board.
     // Must be modified/removed when proper support for voice processing query and control
     // is included in audio framework
     char value[PROPERTY_VALUE_MAX];
     property_get("ro.product.board", value, "");
-    if (mode == NORMAL && !strcmp(value, "herring")) {
+    if (mode == NORMAL &&
+            (!strcmp(value, "herring") || !strcmp(value, "tuna"))) {
         mode = ECHO_SUPPRESSION;
     }
     if (mMode == mode) {
@@ -628,12 +628,13 @@
         return false;
     }
-    //FIXME: temporary code to overcome echo and mic gain issues on herring board.
-    // Must be modified/removed when proper support for voice processing query and control
-    // is included in audio framework
+    // FIXME: temporary code to overcome echo and mic gain issues on herring and tuna boards.
+    // Must be modified/removed when the root cause of the issue is fixed in the hardware or
+    // driver
     char value[PROPERTY_VALUE_MAX];
     property_get("ro.product.board", value, "");